//
//  File.swift
//  kaomojiEmoticonKeyboard
//
//  Created by Robert McGovern on 26/11/2020.
//

import SwiftUI

public extension UIHostingController {
    
    func capture(transparentBackground: Bool = true) -> UIImage {
        let size = sizeThatFits(in: UIScreen.main.bounds.size)
        // makes background transparent
        if (transparentBackground) {
            view.backgroundColor = UIColor.clear
            view.isOpaque = false
            view.layer.isOpaque = false
            view.layer.backgroundColor = UIColor.clear.cgColor
        }
        
        view.bounds.size = size
        view.sizeToFit()
        
        //suggested version
        //        UIGraphicsBeginImageContextWithOptions(view.bounds.size, view.isOpaque, 0)
        //        view.drawHierarchy(in: view.bounds, afterScreenUpdates: true)
        //        let snapshotImage: UIImage = UIGraphicsGetImageFromCurrentImageContext()!
        //        UIGraphicsEndImageContext()
        
        //cleaner ver
        let renderer = UIGraphicsImageRenderer(size: self.view.bounds.size)
        let snapshotImage = renderer.image { ctx in
            self.view.drawHierarchy(in: self.view.bounds, afterScreenUpdates: true)
        }
        
        return snapshotImage
    }
}
