//
//  UIImage+scaleImage.swift
//  kaomojiEmoticonKeyboard
//
//  Created by Robert McGovern on 28/11/2020.
//

import UIKit

public extension UIImage {
    func resizeImage(newWidth: CGFloat) -> UIImage? {
        
        let scale = newWidth / self.size.width
        let newHeight = self.size.height * scale
        UIGraphicsBeginImageContext(CGSize(width: newWidth, height: newHeight))
        self.draw(in: CGRect(x: 0, y: 0, width: newWidth, height: newHeight))
        
        let newImage = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        
        return newImage
    }
    
    func scaleToSize(_ newSize: CGSize) -> UIImage? {
        var newImage: UIImage?
        let newRect = CGRect(x: 0, y: 0, width: newSize.width, height: newSize.height).integral
        UIGraphicsBeginImageContextWithOptions(newSize, false, 0)
        if let context = UIGraphicsGetCurrentContext(), let cgImage = self.cgImage {
            context.interpolationQuality = .high
            let flipVertical = CGAffineTransform(a: 1, b: 0, c: 0, d: -1, tx: 0, ty: newSize.height)
            context.concatenate(flipVertical)
            context.draw(cgImage, in: newRect)
            if let img = context.makeImage() {
                // newImage = UIImage(cgImage: img) -- orig
                let scale = UIScreen.main.scale
                newImage = UIImage(cgImage: img, scale: scale, orientation: .up)
            }
            UIGraphicsEndImageContext()
        }
        return newImage
    }
    
    func scaleToWidth(_ newWidth: CGFloat) -> UIImage? {
        var newImage: UIImage?
        let scale = newWidth / self.size.width
        let newHeight = self.size.height * scale
        
        let newRect = CGRect(x: 0, y: 0, width: newWidth, height: newHeight).integral
        UIGraphicsBeginImageContextWithOptions(CGSize(width: newWidth, height: newHeight), false, 0)
        if let context = UIGraphicsGetCurrentContext(), let cgImage = self.cgImage {
            context.interpolationQuality = .high
            let flipVertical = CGAffineTransform(a: 1, b: 0, c: 0, d: -1, tx: 0, ty: newHeight)
            context.concatenate(flipVertical)
            context.draw(cgImage, in: newRect)
            if let img = context.makeImage() {
                // newImage = UIImage(cgImage: img) -- orig
                let scale = UIScreen.main.scale
                newImage = UIImage(cgImage: img, scale: scale, orientation: .up)
            }
            UIGraphicsEndImageContext()
        }
        return newImage
    }
    
    // don't need, kept because erm
//    static func scaleImage(_ image: UIImage, toNewWidth newWidth: CGFloat) -> UIImage? {
//        var newImage: UIImage?
//        let scale = newWidth / image.size.width
//        let newHeight = image.size.height * scale
//
//        let newRect = CGRect(x: 0, y: 0, width: newWidth, height: newHeight).integral
//        UIGraphicsBeginImageContextWithOptions(CGSize(width: newWidth, height: newHeight), false, 0)
//        if let context = UIGraphicsGetCurrentContext(), let cgImage = image.cgImage {
//            context.interpolationQuality = .high
//            let flipVertical = CGAffineTransform(a: 1, b: 0, c: 0, d: -1, tx: 0, ty: newHeight)
//            context.concatenate(flipVertical)
//            context.draw(cgImage, in: newRect)
//            if let img = context.makeImage() {
//                // newImage = UIImage(cgImage: img) -- orig
//                let scale = UIScreen.main.scale
//                newImage = UIImage(cgImage: img, scale: scale, orientation: .up)
//            }
//            UIGraphicsEndImageContext()
//        }
//        return newImage
//    }
}
